@@ -174,16 +174,20 @@ class AsyncAWSQueryConnection(AsyncConnection):
     STATUS_CODE_REQUEST_TIMEOUT = 408
     STATUS_CODE_NETWORK_CONNECT_TIMEOUT_ERROR = 599
     STATUS_CODE_INTERNAL_ERROR = 500
+    STATUS_CODE_BAD_GATEWAY = 502
     STATUS_CODE_SERVICE_UNAVAILABLE_ERROR = 503
+    STATUS_CODE_GATEWAY_TIMEOUT = 504
 
     STATUS_CODES_SERVER_ERRORS = (
         STATUS_CODE_INTERNAL_ERROR,
+        STATUS_CODE_BAD_GATEWAY,
         STATUS_CODE_SERVICE_UNAVAILABLE_ERROR
     )
 
     STATUS_CODES_TIMEOUT = (
         STATUS_CODE_REQUEST_TIMEOUT,
-        STATUS_CODE_NETWORK_CONNECT_TIMEOUT_ERROR
+        STATUS_CODE_NETWORK_CONNECT_TIMEOUT_ERROR,
+        STATUS_CODE_GATEWAY_TIMEOUT
     )
 
     def __init__(self, sqs_connection, http_client=None,
