@@ -415,6 +415,7 @@ NOTSET = object()
 
 def enable_insecure_serializers(choices=NOTSET):
     """Enable serializers that are considered to be unsafe.
+
     Note:
         Will enable ``pickle``, ``yaml`` and ``msgpack`` by default, but you
         can also specify a list of serializers (by name or content type)
@@ -456,8 +457,8 @@ for ep, args in entrypoints('kombu.serializers'):  # pragma: no cover
     register(ep.name, *args)
 
 
-def prepare_accept_content(l, name_to_type=None):
+def prepare_accept_content(content_types, name_to_type=None):
     name_to_type = registry.name_to_type if not name_to_type else name_to_type
-    if l is not None:
-        return {n if '/' in n else name_to_type[n] for n in l}
-    return l
+    if content_types is not None:
+        return {n if '/' in n else name_to_type[n] for n in content_types}
+    return content_types
