@@ -4,6 +4,7 @@ from __future__ import absolute_import, unicode_literals
 import random
 import sys
 import threading
+import inspect
 
 from collections import OrderedDict
 
@@ -18,7 +19,7 @@ from time import sleep, time
 from vine.utils import wraps
 
 from kombu.five import (
-    UserDict, items, keys, python_2_unicode_compatible, string_t,
+    UserDict, items, keys, python_2_unicode_compatible, string_t, PY3,
 )
 
 from .encoding import safe_repr as _safe_repr
@@ -246,18 +247,18 @@ def maybe_evaluate(value):
     return value
 
 
-def is_list(l, scalars=(Mapping, string_t), iters=(Iterable,)):
+def is_list(obj, scalars=(Mapping, string_t), iters=(Iterable,)):
     """Return true if the object is iterable.
 
     Note:
         Returns false if object is a mapping or string.
     """
-    return isinstance(l, iters) and not isinstance(l, scalars or ())
+    return isinstance(obj, iters) and not isinstance(obj, scalars or ())
 
 
-def maybe_list(l, scalars=(Mapping, string_t)):
+def maybe_list(obj, scalars=(Mapping, string_t)):
     """Return list of one element if ``l`` is a scalar."""
-    return l if l is None or is_list(l, scalars) else [l]
+    return obj if obj is None or is_list(obj, scalars) else [obj]
 
 
 def dictfilter(d=None, **kw):
@@ -372,6 +373,19 @@ def reprcall(name, args=(), kwargs=None, sep=', '):
     )
 
 
+def accepts_argument(func, argument_name):
+    if PY3:
+        argument_spec = inspect.getfullargspec(func)
+        return (
+            argument_name in argument_spec.args or
+            argument_name in argument_spec.kwonlyargs
+        )
+
+    argument_spec = inspect.getargspec(func)
+    argument_names = argument_spec.args
+    return argument_name in argument_names
+
+
 # Compat names (before kombu 3.0)
 promise = lazy
 maybe_promise = maybe_evaluate
